@@ -26,7 +26,7 @@ This file is the "main" file of this package (implements the main function,
 the Server class and the Configuration class).
 """
 
-__version__ = "1.0.1"
+__version__ = "1.0.3"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -971,8 +971,8 @@ class Server:
         origin = environ_getter("HTTP_ORIGIN")
         url = Server.get_baseurl(environ_getter, environ)
 
-        if origin != url:
-            logger_info(f'Bad Origin detected: "{origin}" != "{url}"')
+        if origin.lstrip("htps") != url.lstrip("htps"):
+            logger_info(f"Bad Origin detected: {origin!r} != {url!r}")
             return False
 
         logger_info("Correct Origin detected.")
