@@ -266,17 +266,20 @@ class ScriptInterface {
     */
     set_url_values() {
         let event;
-        let element;
+        let element, element_id;
         let query = location.search;
+        let counters = {};
 
         query = query.substr(1);
         query.split("&").forEach(function(part) {
             let item = part.split("=");
-            element = decodeURIComponent(item[0].replaceAll("+",
+            element_id = element = decodeURIComponent(item[0].replaceAll("+",
                 " "));
+            counters[element] = counters[element] ? counters[element] : 0;
 
             if (element) {
-                element = document.getElementById(element);
+                element = document.getElementById(element) || document.getElementById(element + counters[element]);
+                counters[element_id] += 1;
 
                 if (element) {
                     if (element.type === "checkbox" && item[1] ===
@@ -288,6 +291,10 @@ class ScriptInterface {
                         event = new Event('change');
                         element.dispatchEvent(event);
                     }
+
+                    if (element.onkeyup) {
+                        element.onkeyup({'target': element})
+                    }
                 }
             }
         });
@@ -1090,10 +1097,13 @@ class OutputBuilder {
     anti_XSS(content) {
         for (let value of Object.values(this.user_inputs)) {
             value = value.value;
-            if (value.constructor.name !== "String") continue;
-            let secure_value = this.escape(value);
-            if (value !== secure_value) {
-                content = content.replaceAll(value, secure_value);
+            if (value.constructor.name !== "String" && value.constructor.name !== "Array") continue;
+            if (value.constructor.name !== "Array") value = [value];
+            for (let v of value) {
+                let secure_value = this.escape(v);
+                if (v !== secure_value) {
+                    content = content.replaceAll(v, secure_value);
+                }
             }
         }
 
